==> blancoNLpackGenerator-0.0.88a-src.zip: src/blanco/xliff/util/task/valueobject/BlancoXliffUtilMergeProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.util.task.valueobject;

/**
 * NX [BlancoXliffUtilMergeProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoXliffUtilMergeProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B
     */
    private String fTargetdir;

    /**
     * tB[h [sourcedir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB
     */
    private String fSourcedir;

    /**
     * tB[h [sourcefile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB
     */
    private String fSourcefile;

    /**
     * tB[h [toolid]
     *
     * ڂ̌^ [java.lang.String]<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B
     */
    private String fToolid;

    /**
     * tB[h [settarget]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B
     */
    private boolean fSettarget = false;

    /**
     * tB[h [settargetoverwrite]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B
     */
    private boolean fSettargetoverwrite = false;

    /**
     * tB[h [setalttrans]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * alt-trans Zbg邩ǂB
     */
    private boolean fSetalttrans = false;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [sourcedir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB
     *
     * @param argSourcedir tB[h[sourcedir]Ɋi[l
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h[sourcedir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB
     *
     * @return tB[h[sourcedir]Ɋi[Ăl
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [sourcefile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB
     *
     * @param argSourcefile tB[h[sourcefile]Ɋi[l
     */
    public void setSourcefile(final String argSourcefile) {
        fSourcefile = argSourcefile;
    }

    /**
     * tB[h[sourcefile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB
     *
     * @return tB[h[sourcefile]Ɋi[Ăl
     */
    public String getSourcefile() {
        return fSourcefile;
    }

    /**
     * tB[h [toolid]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B
     *
     * @param argToolid tB[h[toolid]Ɋi[l
     */
    public void setToolid(final String argToolid) {
        fToolid = argToolid;
    }

    /**
     * tB[h[toolid]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B
     *
     * @return tB[h[toolid]Ɋi[Ăl
     */
    public String getToolid() {
        return fToolid;
    }

    /**
     * tB[h [settarget]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B
     *
     * @param argSettarget tB[h[settarget]Ɋi[l
     */
    public void setSettarget(final boolean argSettarget) {
        fSettarget = argSettarget;
    }

    /**
     * tB[h[settarget]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B
     *
     * @return tB[h[settarget]Ɋi[Ăl
     */
    public boolean getSettarget() {
        return fSettarget;
    }

    /**
     * tB[h [settargetoverwrite]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B
     *
     * @param argSettargetoverwrite tB[h[settargetoverwrite]Ɋi[l
     */
    public void setSettargetoverwrite(final boolean argSettargetoverwrite) {
        fSettargetoverwrite = argSettargetoverwrite;
    }

    /**
     * tB[h[settargetoverwrite]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B
     *
     * @return tB[h[settargetoverwrite]Ɋi[Ăl
     */
    public boolean getSettargetoverwrite() {
        return fSettargetoverwrite;
    }

    /**
     * tB[h [setalttrans]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * alt-trans Zbg邩ǂB
     *
     * @param argSetalttrans tB[h[setalttrans]Ɋi[l
     */
    public void setSetalttrans(final boolean argSetalttrans) {
        fSetalttrans = argSetalttrans;
    }

    /**
     * tB[h[setalttrans]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * alt-trans Zbg邩ǂB
     *
     * @return tB[h[setalttrans]Ɋi[Ăl
     */
    public boolean getSetalttrans() {
        return fSetalttrans;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.util.task.valueobject.BlancoXliffUtilMergeProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",sourcefile=" + fSourcefile);
        buf.append(",toolid=" + fToolid);
        buf.append(",settarget=" + fSettarget);
        buf.append(",settargetoverwrite=" + fSettargetoverwrite);
        buf.append(",setalttrans=" + fSetalttrans);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.1.20-src.zip: src/blanco/xliff/util/task/valueobject/BlancoXliffUtilMergeProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.util.task.valueobject;

/**
 * NX [BlancoXliffUtilMergeProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoXliffUtilMergeProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B
     */
    private String fTargetdir;

    /**
     * tB[h [sourcedir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB
     */
    private String fSourcedir;

    /**
     * tB[h [sourcefile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB
     */
    private String fSourcefile;

    /**
     * tB[h [toolid]
     *
     * ڂ̌^ [java.lang.String]<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B
     */
    private String fToolid;

    /**
     * tB[h [settarget]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B
     */
    private boolean fSettarget = false;

    /**
     * tB[h [settargetoverwrite]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B
     */
    private boolean fSettargetoverwrite = false;

    /**
     * tB[h [setalttrans]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * Zbg target ̓e alt-trans ɃZbg邩ǂB
     */
    private boolean fSetalttrans = false;

    /**
     * tB[h [copyalttrans]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * ͌ alt-trans  o͐ alt-trans ɃZbg邩ǂB
     */
    private boolean fCopyalttrans = false;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C()܂܂fBNgBɏ܂BύX  XLIFF ݂̂Ɏ{܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [sourcedir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB
     *
     * @param argSourcedir tB[h[sourcedir]Ɋi[l
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h[sourcedir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)܂܂fBNgBӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcefileƔrpB
     *
     * @return tB[h[sourcedir]Ɋi[Ăl
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [sourcefile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB
     *
     * @param argSourcefile tB[h[sourcefile]Ɋi[l
     */
    public void setSourcefile(final String argSourcefile) {
        fSourcefile = argSourcefile;
    }

    /**
     * tB[h[sourcefile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C(E)Bӂɑ݂Ȃ trans-unit (Babel URI) ͖܂BsourcedirƔrpB
     *
     * @return tB[h[sourcefile]Ɋi[Ăl
     */
    public String getSourcefile() {
        return fSourcefile;
    }

    /**
     * tB[h [toolid]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B
     *
     * @param argToolid tB[h[toolid]Ɋi[l
     */
    public void setToolid(final String argToolid) {
        fToolid = argToolid;
    }

    /**
     * tB[h[toolid]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * }[W{ۂɗp tool-idBnlpack  pleiades Ȃǂw肵܂Balt-trans ŗp܂B
     *
     * @return tB[h[toolid]Ɋi[Ăl
     */
    public String getToolid() {
        return fToolid;
    }

    /**
     * tB[h [settarget]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B
     *
     * @param argSettarget tB[h[settarget]Ɋi[l
     */
    public void setSettarget(final boolean argSettarget) {
        fSettarget = argSettarget;
    }

    /**
     * tB[h[settarget]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * trans-unit  target ɂāAlZbg邩ǂBȂA{I source 񂪈v邱ƂOƂȂ܂B
     *
     * @return tB[h[settarget]Ɋi[Ăl
     */
    public boolean getSettarget() {
        return fSettarget;
    }

    /**
     * tB[h [settargetoverwrite]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B
     *
     * @param argSettargetoverwrite tB[h[settargetoverwrite]Ɋi[l
     */
    public void setSettargetoverwrite(final boolean argSettargetoverwrite) {
        fSettargetoverwrite = argSettargetoverwrite;
    }

    /**
     * tB[h[settargetoverwrite]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * trans-unit  target ɂāA݂̗Lɂ炸lZbg邩ǂB|󕨂̗D揇ʂ݂ꍇ̃}[WɂĂ̂݃Zbg܂B
     *
     * @return tB[h[settargetoverwrite]Ɋi[Ăl
     */
    public boolean getSettargetoverwrite() {
        return fSettargetoverwrite;
    }

    /**
     * tB[h [setalttrans]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Zbg target ̓e alt-trans ɃZbg邩ǂB
     *
     * @param argSetalttrans tB[h[setalttrans]Ɋi[l
     */
    public void setSetalttrans(final boolean argSetalttrans) {
        fSetalttrans = argSetalttrans;
    }

    /**
     * tB[h[setalttrans]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * Zbg target ̓e alt-trans ɃZbg邩ǂB
     *
     * @return tB[h[setalttrans]Ɋi[Ăl
     */
    public boolean getSetalttrans() {
        return fSetalttrans;
    }

    /**
     * tB[h [copyalttrans]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * ͌ alt-trans  o͐ alt-trans ɃZbg邩ǂB
     *
     * @param argCopyalttrans tB[h[copyalttrans]Ɋi[l
     */
    public void setCopyalttrans(final boolean argCopyalttrans) {
        fCopyalttrans = argCopyalttrans;
    }

    /**
     * tB[h[copyalttrans]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * ͌ alt-trans  o͐ alt-trans ɃZbg邩ǂB
     *
     * @return tB[h[copyalttrans]Ɋi[Ăl
     */
    public boolean getCopyalttrans() {
        return fCopyalttrans;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.util.task.valueobject.BlancoXliffUtilMergeProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",sourcefile=" + fSourcefile);
        buf.append(",toolid=" + fToolid);
        buf.append(",settarget=" + fSettarget);
        buf.append(",settargetoverwrite=" + fSettargetoverwrite);
        buf.append(",setalttrans=" + fSetalttrans);
        buf.append(",copyalttrans=" + fCopyalttrans);
        buf.append("]");
        return buf.toString();
    }
}
